#------------------------------------------------------------------------------
# This SPEC file controls the building of custom CrossOver RPM packages.
#
#------------------------------------------------------------------------------


#------------------------------------------------------------------------------
#   Options (see /usr/lib/rpm/macros for documentation)
#------------------------------------------------------------------------------

# Hardcode the compression algorithm to w9.gzdio which is the historical
# default. This way we produce backwards compatible packages on systems
# which use newer defaults (lzma in particular).
%define _binary_payload              w9.gzdio

# Hardcode the file digest algorithm to MD5 (1) which is the historical
# default. This way we produce backwards compatible packages on systems
# which use newer defaults.
%define _binary_filedigest_algorithm 1


#------------------------------------------------------------------------------
#   Prologue information
#------------------------------------------------------------------------------
Summary         : Run Windows applications like MS Office
License         : Proprietary; includes substantial Free Software components.
Name            : @rpm_package@
Version         : 9.0.0
Release         : @release@
Provides        : @product_id@5
Group           : Applications/Emulators
ExclusiveArch   : %{ix86}

BuildRoot	: @buildroot@
Url             : http://www.codeweavers.com
Packager        : CrossOver Packager <info@codeweavers.com>

# The prefix is pretty important; RPM uses this to figure out
# how to make a package relocatable
Prefix          : /opt


#------------------------------------------------------------------------------
#   Generate our own dependency information
#------------------------------------------------------------------------------
Autoreqprov     : No

# For our scripts
Requires        : /bin/sh, /usr/bin/perl

# For the GUI (including cxmessage, etc.)
Requires        : /usr/bin/env, python >= 2.4,

# Support for 32bit binaries
Requires        : ld-linux.so.2

# The C library
Requires        : libc.so.6, libc.so.6(GLIBC_2.3), libdl.so.2, libm.so.6

# The gcc support library
Requires        : libgcc_s.so.1

# X11 support for Wine and cxsetup
Requires        : libICE.so.6, libSM.so.6, libX11.so.6, libXext.so.6


# For winex11.drv/wintab.c
Requires        : libXi.so.6

# Needed for FreeType, msxml3.dll and wldap32.dll
Requires        : libz.so.1




#------------------------------------------------------------------------------
#   Description
#------------------------------------------------------------------------------
%Description
CrossOver Linux Professional makes it possible to use Windows applications
such as Microsoft Office, Quicken, and Lotus Notes.


#------------------------------------------------------------------------------
#   Files listing
#------------------------------------------------------------------------------
%files
%defattr(-,root,root)

%docdir            @cx_root@/doc

@dir_list@
@file_list@


%pre
#------------------------------------------------------------------------------
#   Pre install script
#------------------------------------------------------------------------------

# Setup logging
if [ -n "$CX_LOG" ]
then
    [ "$CX_LOG" = "-" ] || exec 2>>"$CX_LOG"
    echo >&2
    echo "***** `date`" >&2
    echo "Starting: $0 $@" >&2
    set -x
fi

if [ -z "$RPM_INSTALL_PREFIX" ]
then
    RPM_INSTALL_PREFIX=/opt
fi
CX_ROOT="$RPM_INSTALL_PREFIX/@product_id@"
export CX_ROOT

if [ -d "$CX_ROOT/.manifest" ]
then
    if [ -n "$DISPLAY" ]
    then
        cxmessage="$CX_ROOT/bin/cxmessage"
        if [ ! -f "$cxmessage" -o ! -x "$cxmessage" ]
        then
            cxmessage="xmessage"
        fi
        "$cxmessage" \
            -title "Unable to install" \
            -buttons "Abort" \
            -default "Abort" \
            "This RPM package cannot be installed on top of a Loki package." &
    fi
    echo "This CrossOver Linux Professional RPM package cannot be installed on top of a Loki package." >&2
    exit 1
fi

if [ "$1" = "1" ]
then
    mode="install"
else
    mode="upgrade"
fi

if [ "$mode" = "install" ]
then
    if [ -z "$CX_PRODUCT_ID" ]
    then
        CX_PRODUCT_ID="cxoffice"
    fi
elif [ -f "$CX_ROOT/.productid" ]
then
    CX_PRODUCT_ID=`cat "$CX_ROOT/.productid"`
else
    CX_PRODUCT_ID="cxoffice"
fi
productid="$CX_PRODUCT_ID"


# This script expects CX_ROOT, productid and mode to be set

# Validate the productid
echo "$productid" | LC_ALL=C egrep '^[a-zA-Z0-9_][a-zA-Z0-9_][a-zA-Z0-9_][a-zA-Z0-9_][a-zA-Z0-9_]*$' >/dev/null
if [ $? -ne 0 ]
then
    echo "The product id '$productid' is not valid" >&2
    exit 1
fi

if [ "$mode" = "upgrade" ]
then
    if [ -f "$CX_ROOT/.productid" ]
    then
        old_productid=`cat "$CX_ROOT/.productid"`
    else
        old_productid="cxoffice"
    fi
    if [ "$productid" != "$old_productid" ]
    then
        echo "An upgrade cannot change the product id" >&2
        exit 1
    fi
fi

# Remove generated files that old packages incorrectly leave around
rm -f "$CX_ROOT"/support/icons/*.png


# RPM only deletes this file after the postinstall script is run!
rm -f "$CX_ROOT/lib/nptl"/libwine.so*


%post
#------------------------------------------------------------------------------
#   Post install script
#------------------------------------------------------------------------------

# Setup logging
if [ -n "$CX_LOG" ]
then
    [ "$CX_LOG" = "-" ] || exec 2>>"$CX_LOG"
    echo >&2
    echo "***** `date`" >&2
    echo "Starting: $0 $@" >&2
    set -x
fi

if [ -z "$RPM_INSTALL_PREFIX" ]
then
    RPM_INSTALL_PREFIX=/opt
fi
CX_ROOT="$RPM_INSTALL_PREFIX/@product_id@"
export CX_ROOT

if [ "$1" = "1" ]
then
    mode="install"
else
    mode="upgrade"
fi
oldver=""

if [ "$mode" = "install" ]
then
    if [ -z "$CX_PRODUCT_ID" ]
    then
        CX_PRODUCT_ID="@product_id@"
    fi
elif [ -f "$CX_ROOT/.productid" ]
then
    CX_PRODUCT_ID=`cat "$CX_ROOT/.productid"`
else
    CX_PRODUCT_ID="@product_id@"
fi
productid="$CX_PRODUCT_ID"

# This script expects CX_ROOT, productid, mode and oldver to be set
builtin_product_id="cxoffice"

if [ "$mode" = "install" ]
then
    if [ "$productid" != "$builtin_product_id" ]
    then
        echo "$productid" >"$CX_ROOT/.productid"
    else
        rm -f "$CX_ROOT/.productid"
    fi
fi

uid=`id | sed -e 's/^uid=\([0-9]*\)(.*/\1/' -e 't' -e 'd'`

# Check that we can use $HOME
if [ -n "$HOME" ]
then
    if [ ! -d "$HOME" -o ! -w "$HOME" ]
    then
        unset HOME
    else
        owner=`ls -Llnd "$HOME" | sed -e 's/^[^ ]*  *[^ ]*  *\([0-9]*\)  *.*$/\1/'`
        if [ "$uid" != "$owner" -a "$owner" != "0" ]
        then
            # Probably an 'su' that did not update $HOME
            unset HOME
        fi
    fi
fi

# These files are no longer needed (was used by version 4.x)
if [ "$uid" = "0" -a -f "/sbin/conf.d/SuSEconfig.zz$productid-vfolders" ]
then
    rm -f "/sbin/conf.d/SuSEconfig.zz$productid-vfolders"
fi
rm -f "$CX_ROOT/lib/xml/libperl.so.5.8"

# Icons have moved to share/icons
rm -f "$CX_ROOT"/support/*.png

# We don't need the 2007 DST bottle hook anymore
rm -f "$CX_ROOT"/support/scripts.d/??.dst2007patch
rmdir -f "$CX_ROOT"/support/scripts.d 2>/dev/null

if [ "$mode" = "upgrade" ]
then
    if [ -n "$HOME" -a -f "$HOME/.$productid/$productid.conf" ]
    then
        mv "$HOME/.$productid/$productid".conf* "$CX_ROOT/etc"
        rmdir "$HOME/.$productid" 2>/dev/null
    fi
    if [ "$uid" = "0" ]
    then
        if [ -f "/etc/$productid.conf" ]
        then
            mv "/etc/$productid".conf* "$CX_ROOT/etc"
        fi
        if [ -n "$HOME" ]
        then
            rm "$HOME/.$productid/dotwine" 2>/dev/null
            rmdir "$HOME/.$productid" 2>/dev/null
        fi
    fi
fi

# Create or upgrade the configuration file
if [ -f "$CX_ROOT/.uninstalled" ]
then
    rm -f "$CX_ROOT/.uninstalled"
    install_bottles="--install-bottles"
else
    install_bottles=""
fi
"$CX_ROOT/lib/cxupgrade" --productid "$productid" --old-version "$oldver" $install_bottles

if [ "$mode" = "install" -a "$uid" = "0" ]
then
    chmod 0644 "$CX_ROOT/etc/$productid.conf"
fi

setup_selinux()
{
    # If we change the context of our files, it helps with Fedora installs.
    # Note that we require both chcon and secon; Debian systems come with
    # chcon, but it doesn't work at all unless you've installed some extra
    # utilities. This is rather crude, but I was unable to find a more
    # sophisticated way to probe for contexts being enabled, and we had at
    # least one FC6 user getting errors.
    type chcon >/dev/null 2>&1
    has_chcon=$?
    type secon >/dev/null 2>&1
    has_secon=$?
    if [ $has_chcon -eq 0 -a $has_secon -eq 0 ]
    then
        chcon -u system_u -r object_r -t bin_t "$CX_ROOT"/bin/*
        chcon -u system_u -r object_r -t lib_t "$CX_ROOT"/lib/*
        chcon -u system_u -r object_r -t lib_t "$CX_ROOT"/lib/tcl/*
        chcon -u system_u -r object_r -t wine_exec_t "$CX_ROOT"/bin/wineloader
        chcon -u system_u -r object_r -t textrel_shlib_t "$CX_ROOT"/lib/wine/*
        if [ $? -ne 0 ]
        then
            chcon -u system_u -r object_r -t lib_t "$CX_ROOT"/lib/wine/*
        fi
    fi
}
if [ -z "$CX_LOG" ]
then
    setup_selinux 2>/dev/null
else
    setup_selinux
fi


# Add/Update the menus and associations
"$CX_ROOT/bin/cxmenu" --crossover --install
"$CX_ROOT/bin/cxassoc" --crossover --install

exit 0


%preun
#------------------------------------------------------------------------------
#   Pre uninstallation script
#------------------------------------------------------------------------------

# Setup logging
if [ -n "$CX_LOG" ]
then
    [ "$CX_LOG" = "-" ] || exec 2>>"$CX_LOG"
    echo >&2
    echo "***** `date`" >&2
    echo "Starting: $0 $@" >&2
    set -x
fi

# If we're doing an upgrade, then do not uninstall ourselves
if [ "$1" != "0" ]
then
    exit 0
fi

if [ -z "$RPM_INSTALL_PREFIX" ]
then
    RPM_INSTALL_PREFIX=/opt
fi
CX_ROOT="$RPM_INSTALL_PREFIX/@product_id@"
export CX_ROOT

if [ -f "$CX_ROOT/.productid" ]
then
    productid=`cat "$CX_ROOT/.productid"`
else
    productid="@product_id@"
fi

[ -n "$CX_PURGE" ] || CX_PURGE="desktopdata"
export CX_PURGE


# This script expects CX_ROOT and productid to be set
# Note: this script may also be called in case the installation is aborted
builtin_product_id="cxoffice"

if [ -z "$CX_PURGE" ]
then
    CX_PURGE="all"
fi

if [ "$CX_PURGE" = "desktopdata" -o "$CX_PURGE" = "all" ]
then
    scopes=""
    uid=`id | sed -e 's/^uid=\([0-9]*\)(.*/\1/' -e 't' -e 'd'`
    [ "$uid" = "0" ] && scopes="managed"
    [ -n "$HOME" ] && scopes="$scopes private"
    for scope in $scopes
    do
        if [ -x "$CX_ROOT/bin/cxmenu" ]
        then
            "$CX_ROOT/bin/cxmenu" --removeall --pattern "$productid-" --scope $scope --ignorelist ""
        fi
        if [ -x "$CX_ROOT/bin/cxassoc" ]
        then
            "$CX_ROOT/bin/cxassoc" --removeall --pattern "$productid-" --scope $scope --ignorelist ""
        fi
        if [ -x "$CX_ROOT/bin/cxnsplugin" ]
        then
            "$CX_ROOT/bin/cxnsplugin" --removeall --pattern "$productid-" --scope $scope
        fi
    done
    rm -f "$CX_ROOT"/share/icons/*.png
fi

rm -f "$CX_ROOT/lib/python"/*.pyc

# We must delete any file generated at runtime before 'rpm -e'
# tries to delete the installed files and directories.
# This script expects CX_ROOT and productid to be set

if [ -z "$CX_PURGE" ]
then
    CX_PURGE="all"
fi

if [ "$CX_PURGE" = "desktopdata" -o "$CX_PURGE" = "all" ]
then
    rm -rf "$CX_ROOT"/support/desktopdata
fi

if [ "$CX_PURGE" = "all" ]
then
    rm -f  "$CX_ROOT/etc/$productid".conf*
    rm -f  "$CX_ROOT"/support/default
    rm -rf "$CX_ROOT"/support/installers
    rm -f  "$CX_ROOT"/.uninstalled

    # Delete bottles. For OEM bottles, 'cxbottle.conf' may have already been
    # removed by the RPM or Debian packaging system. But these are managed
    # bottles so we can check for 'files' instead.
    for landmark in cxbottle.conf files
    do
        ls -d "$CX_ROOT"/support/*/$landmark 2>/dev/null | while read bottlefile
        do
            dir=`dirname "$bottlefile"`
            rm -rf "$dir"
        done
    done

    rmdir "$CX_ROOT"/support 2>/dev/null
    rm -f  "$CX_ROOT/.productid"

    if [ -n "$HOME" ]
    then
        # Delete dotdir but check ownership first in case
        # it does not belong to us (e.g. because $HOME is wrong)
        dotdir="$HOME/.$productid"
        if [ -d "$dotdir" ]
        then
            uid=`id | sed -e 's/^uid=\([0-9]*\)(.*/\1/' -e 't' -e 'd'`
            owner=`ls -lnd "$dotdir" | sed -e 's/^[^ ]*  *[^ ]*  *\([0-9]*\)  *.*$/\1/'`
            if [ "$owner" = "$uid" ]
            then
                rm -rf "$dotdir"
            fi
        fi
    fi
else
    touch "$CX_ROOT/.uninstalled"
fi

exit 0


%postun
#------------------------------------------------------------------------------
#   Post uninstallation script
#------------------------------------------------------------------------------
